-- Addon:	LockoutChecker
-- Author:	Spielstein@Curse


if GetLocale() ~= "enGB" and GetLocale() ~= "enUS" and GetLocale() ~= "deDE" then
	return
end


------------------------------------------
--		GUI								--
------------------------------------------


-- 
function LockoutChecker:CreateGUI(parentFrame, dungeonSet, buttonScript)


	-- Local variables
	local xAxisOffset = 0
	local yAxisOffset = 0
	local xDimension = 180
	local yDimension = 110
	local betweenOffset = 1

	local i, j, dungeonName
	local _


	-- MainFrame
	local gui = CreateFrame("Frame", "LockoutCheckerGUI", parentFrame, "TooltipBorderedFrameTemplate")
	gui:SetSize(1100, 600)
	gui:SetPoint("CENTER")
	gui:SetFrameStrata("HIGH")

	local closeButton = CreateFrame("Button", nil, gui, "UIPanelCloseButton")
	closeButton:SetPoint("TOPRIGHT")
	closeButton:SetScript("OnClick", function (self)
		self:GetParent():Hide()
	end)
	gui.closeButton = closeButton


	-- Scrollframe 
	local scrollframe = CreateFrame("ScrollFrame", nil, gui) 
	scrollframe:SetPoint("TOPLEFT", 10, -65) 
	scrollframe:SetPoint("BOTTOMRIGHT", -10, 10) 
	gui.scrollframe = scrollframe 
	 

	-- Scrollbar 
	local scrollbar = CreateFrame("Slider", nil, scrollframe, "UIPanelScrollBarTemplate") 
	scrollbar:SetPoint("TOPLEFT", gui, "TOPRIGHT", 4, -16) 
	scrollbar:SetPoint("BOTTOMLEFT", gui, "BOTTOMRIGHT", 4, 16) 
	scrollbar:SetMinMaxValues(1, 800) 
	scrollbar:SetValueStep(1) 
	scrollbar.scrollStep = 1
	scrollbar:SetValue(0) 
	scrollbar:SetWidth(16) 

	-- Functionality for the scrollbar
	scrollbar:SetScript("OnValueChanged", 
		function (self, value) 
			self:GetParent():SetVerticalScroll(value) 
		end)

	-- Scroll wheel functionality
	scrollframe:EnableMouseWheel(true)
    scrollframe:SetScript("OnMouseWheel", 
        function (self, value) 
            local minV, maxV = scrollbar:GetMinMaxValues()
            local currV = scrollbar:GetValue()
            local height, viewheight = scrollframe:GetHeight(), scrollframe.content:GetHeight()
            
            if value > 0 and currV - minV > 0 then
                scrollbar:SetValue(currV - value*(maxV/((height - viewheight)/(maxV*0.028)))) 
            end            
            if value < 0 and maxV - currV > 0 then
                scrollbar:SetValue(currV - value*(maxV/((height - viewheight)/(maxV*0.028))))
            end
        end) 

    -- ScrollBarBG
	local scrollbg = scrollbar:CreateTexture(nil, "BACKGROUND") 
	scrollbg:SetAllPoints(scrollbar) 
	scrollbg:SetColorTexture(0, 0, 0, 0.4) 
	gui.scrollbar = scrollbar 
	 
	-- Content frame 
	local content = CreateFrame("Frame", nil, scrollframe) 
	content:SetSize(128, 128) 
	scrollframe.content = content 
	 
	scrollframe:SetScrollChild(content)


	-- 
	gui.fields = {}

	for i = 0, 5 do

		gui.fields[i+1] = {}
		j = 1
		local lastDungeon = ""

		-- Fields for the CharacterNames
		gui.fields[i+1]["cNames"] = CreateFrame("Frame", "LockoutCheckerField_" .. i .. "_" .. "cNames", gui, nil)
		gui.fields[i+1]["cNames"]:SetSize(xDimension, yDimension/2)
		gui.fields[i+1]["cNames"]:SetPoint("TOPLEFT", xAxisOffset + xDimension*i + betweenOffset + 10, yAxisOffset - yDimension*(j-1) - betweenOffset -5)

		gui.fields[i+1]["cNames"].text = gui.fields[i+1]["cNames"]:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
		gui.fields[i+1]["cNames"].text:SetPoint("CENTER", gui.fields[i+1]["cNames"], "CENTER")

		gui.fields[i+1]["cNames"].SetText = function (self, txt)
			self.text:SetText(txt)
		end

		-- Fields for the dungeon infos
		for _, dungeonName in ipairs(dungeonSet) do
			gui.fields[i+1][dungeonName] = CreateFrame("Frame", "LockoutCheckerField_" .. i .. "_" .. dungeonName, content, nil)
			if dungeonName == "Return to Karazhan" then
				gui.fields[i+1][dungeonName]:SetSize(xDimension, 2* yDimension)
			else
				gui.fields[i+1][dungeonName]:SetSize(xDimension, yDimension)
			end
			if j == 1 then
				gui.fields[i+1][dungeonName]:SetPoint("TOPLEFT", xAxisOffset + xDimension*i + betweenOffset, yAxisOffset - yDimension*(j-1) - betweenOffset)
			else
				gui.fields[i+1][dungeonName]:SetPoint("TOP", gui.fields[i+1][lastDungeon], "BOTTOM", 0, betweenOffset)
			end

			gui.fields[i+1][dungeonName].text = gui.fields[i+1][dungeonName]:CreateFontString(nil, "ARTWORK", "GameFontHighlight")
			gui.fields[i+1][dungeonName].text:SetPoint("CENTER", gui.fields[i+1][dungeonName], "CENTER")

			gui.fields[i+1][dungeonName].SetText = function (self, txt)
				self.text:SetText(txt)
			end

			gui.fields[i+1][dungeonName].Append = function (self, txt)
				local previousValue = self.text:GetText()
				self.text:SetText((previousValue == nil) and txt or self.text:GetText() .. txt)
			end

			j = j + 1
			lastDungeon = dungeonName
		end
	end

	gui.fields[1]["cNames"]:Hide()


	-- Sync button
	local syncButton = CreateFrame("Button", nil, gui, "UIPanelButtonTemplate")
	syncButton:SetText("Sync")
	syncButton:SetPoint("CENTER", gui.fields[1]["cNames"], "CENTER")
	syncButton:SetWidth(100)
	syncButton:SetHeight(25)
	syncButton:SetScript("OnClick", buttonScript)

	syncButton.elapsedTime = 0
	syncButton.maxTime = 3

	gui.syncButton = syncButton


	-- Hide GUI on StartUp
	gui:Hide()
	-- Make GUI movable
	gui:RegisterForDrag("LeftButton")
	gui:SetMovable(true)
	gui:EnableMouse(true)
	gui:SetScript("OnDragStart", gui.StartMoving)
	gui:SetScript("OnDragStop", gui.StopMovingOrSizing)
	-- Make GUI closable by Escape key
	tinsert(UISpecialFrames, gui:GetName())


	-- Return finished GUI
	return gui
end


------------------------------------------
--		End of Script					--
------------------------------------------